@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.92 2005/07/05 16:01:12 vnoel Exp $ */
+/* $Id: gdict-applet.c,v 1.94 2005/10/06 14:06:45 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -17,6 +17,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <panel-applet.h>
+#include <string.h>
 
 #include "gdict-app.h"
 #include "gdict-about.h"
@@ -102,7 +103,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
   GDictApplet *applet = data;
   gchar *text;
   
-  text = gtk_selection_data_get_text (sd);
+  text = (gchar *) gtk_selection_data_get_text (sd);
   
   if (text && *text) {
     gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), text);
