@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.53 2005/05/25 15:01:40 vnoel Exp $ */
+/* $Id: gdict-defbox.c,v 1.56 2005/09/23 14:34:39 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -16,6 +16,8 @@
 #  include <config.h>
 #endif
 
+#include <string.h>
+#include <math.h>
 #include <glib/gi18n.h>
 #include "gdict-defbox.h"
 #include "gdict-app.h"
@@ -390,14 +392,11 @@ gdict_defbox_new (gpointer gdict)
 		context = gtk_widget_get_pango_context (GTK_WIDGET (defbox));
 		fontdesc = pango_context_get_font_description (context);
 
-		if (pango_font_description_get_family (fontdesc)) {
+		if (pango_font_description_get_family (fontdesc))
 			defbox->fontname = g_strdup(pango_font_description_get_family (fontdesc));
-			defbox->fontsize = pango_font_description_get_size (fontdesc);
-		}
 		
     defbox->gdict = gdict;
     defbox->context = GDICT_WINDOW(gdict)->context;
-		defbox->fontsize = 10;
     gdict_defbox_setup_tags (defbox);  
     g_signal_connect (G_OBJECT(defbox), "event-after", 
                       G_CALLBACK (gdict_defbox_event_after), gdict);
@@ -458,7 +457,7 @@ gdict_defbox_lookup (GDictDefbox *defbox, gchar *text)
     defbox->def_cmd->user_data = defbox;
 
     if (dict_command_invoke (defbox->def_cmd, defbox->context) < 0)
-	return -1;
+			return -1;
 
     return 0;
 }
@@ -496,33 +495,6 @@ gdict_defbox_set_font (GDictDefbox *defbox, gchar *fontname)
 	gdict_window_store_font (defbox->gdict);
 }
 
-void
-gdict_defbox_set_fontsize (GDictDefbox *defbox, int fontsize)
-{
-	PangoFontDescription *fontdesc;
-	PangoContext *context;
-	
-	context = gtk_widget_get_pango_context (GTK_WIDGET(defbox));
-	fontdesc = pango_context_get_font_description (context);
-	pango_font_description_set_size (fontdesc, fontsize*PANGO_SCALE);
-	gtk_widget_modify_font (GTK_WIDGET(defbox), fontdesc);
-	defbox->fontsize = fontsize;
-}	
-
-void
-gdict_defbox_zoom_in (GDictDefbox *defbox)
-{
-	defbox->fontsize = MIN (defbox->fontsize + 1, 24);
-	gdict_defbox_set_fontsize (defbox, defbox->fontsize);
-}	
-
-void
-gdict_defbox_zoom_out (GDictDefbox *defbox)
-{
-	defbox->fontsize = MAX (defbox->fontsize - 1, 6);
-	gdict_defbox_set_fontsize (defbox, defbox->fontsize);
-}	
-
 /* gdict_defbox_find
  * Finds a string of text in the current definition
  */
