@@ -1,7 +1,4 @@
-#ifndef __GDICT_DEFBOX_H_
-#define __GDICT_DEFBOX_H_
-
-/* $Id: gdict-defbox.h,v 1.12 2005/01/18 20:56:55 vnoel Exp $ */
+/* $Id: gdict-defbox.h,v 1.15 2005/09/23 14:34:39 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -15,6 +12,11 @@
  *
  */
 
+#ifndef GDICT_DEFBOX_H
+#define GDICT_DEFBOX_H
+
+G_BEGIN_DECLS
+
 #include <gtk/gtk.h>
 #include "dict.h"
 
@@ -37,6 +39,7 @@ struct _GDictDefbox
     dict_command_t *def_cmd;
     gchar          *database;
     gpointer       gdict;
+	  gchar *fontname;
 };
 
 struct _GDictDefboxClass 
@@ -62,5 +65,8 @@ void       gdict_defbox_reset      (GDictDefbox *defbox,
 void gdict_defbox_prepare_print    (GDictDefbox *defbox);
 void gdict_defbox_print_preview (GDictDefbox *defbox);
 gchar     *gdict_defbox_get_word   (GDictDefbox *defbox);
+void gdict_defbox_set_font (GDictDefbox *defbox, gchar *fontname);
+
+G_END_DECLS
 	
-#endif /* __GDICT_DEFBOX_H_ */
+#endif /* GDICT_DEFBOX_H */
