@@ -185,9 +185,15 @@ static const char *ui_description =
 GList *regexp_db = NULL, *descript_db = NULL, *actions_db = NULL;
 ConfigData *cfg = NULL;
 gchar *file_to_open;
+static gchar *config_prefix = NULL;
+static gchar *sm_client_id = NULL;
+static int screen = 0;
 
 GOptionContext *context;
 GOptionEntry options[] = {
+    { "sm-config-prefix", 0, 0, G_OPTION_ARG_STRING, &config_prefix, "", NULL},
+    { "sm-client-id", 0, 0, G_OPTION_ARG_STRING, &sm_client_id, "", NULL},
+    { "screen", 0, 0, G_OPTION_ARG_INT, &screen, "", NULL},
 	{ NULL }
 };
 
@@ -202,7 +208,8 @@ logview_save_prefs (LogviewWindow *logview)
       log = list->data;
       user_prefs->logs = g_slist_append (user_prefs->logs, log->name);
 	}
-  user_prefs->logfile = logview->curlog->name;
+  if (logview->curlog)
+    user_prefs->logfile = logview->curlog->name;
 	user_prefs->fontsize = logview->fontsize;
 	if (restoration_complete)
 		prefs_save (client, user_prefs);
@@ -218,7 +225,7 @@ destroy (GObject *object, gpointer data)
 {
    LogviewWindow *window = data;
    logview_windows = g_slist_remove (logview_windows, window);
-   if (window->curlog->monitored)
+   if (window->curlog && window->curlog->monitored)
 	   monitor_stop (window);
    if (logview_windows == NULL) {
 	   if (window->curlog && !(window->curlog->display_name))
@@ -237,8 +244,10 @@ save_session (GnomeClient *gnome_client, gint phase,
               gpointer client_data)
 {
    gchar **argv;
-   gint numlogs, i=0;
+   gint numlogs, i=1;
    GSList *list;
+   GList *logs;
+   Log *log;
 
    numlogs = logview_count_logs ();
 
@@ -247,14 +256,14 @@ save_session (GnomeClient *gnome_client, gint phase,
 
    for (list = logview_windows; list != NULL; list = g_slist_next (list)) {
 	   LogviewWindow *w = list->data;
-	   if (w->curlog) {
-		   argv[i++] = g_strdup_printf ("%s", w->curlog->name);
+       for (logs = w->logs; logs != NULL; logs = g_list_next (logs)) {
+           log = logs->data;
+		   argv[i++] = g_strdup_printf ("%s", log->name);
 	   }
    }
    
    gnome_client_set_clone_command (gnome_client, numlogs+1, argv);
    gnome_client_set_restart_command (gnome_client, numlogs+1, argv);
-
    g_free (argv);
 
    return TRUE;
@@ -375,10 +384,11 @@ main (int argc, char *argv[])
 
    /* Open regular logs and add each log passed as a parameter */
 
-	 logview = LOGVIEW_WINDOW(logview_create_window ());
-	 logview_add_logs_from_names (logview, user_prefs->logs);
-	 loglist_select_log_from_name (logview, user_prefs->logfile);
-   if (argc > 1) {
+   logview = LOGVIEW_WINDOW(logview_create_window ());
+   if (argc == 1) {
+       logview_add_logs_from_names (logview, user_prefs->logs);
+       loglist_select_log_from_name (logview, user_prefs->logfile);
+   } else {
 	   for (i=1; i<argc; i++) {
 		   file_to_open = argv[i];
 			 logview_add_log_from_name (logview, file_to_open);
@@ -825,7 +835,7 @@ FileSelectResponse (GtkWidget * chooser, gint response, gpointer data)
    if (f != NULL) {
 	   /* Check if the log is not already opened */
 	   GList *list;
-		 Log *log;
+		 Log *log, *tl;
 	   for (list = logview->logs; list != NULL; list = g_list_next (list)) {
 		   log = list->data;
 		   if (g_ascii_strncasecmp (log->name, f, 255) == 0) {
@@ -834,7 +844,6 @@ FileSelectResponse (GtkWidget * chooser, gint response, gpointer data)
 		   }
 	   }
 
-	   Log *tl;
 	   if ((tl = OpenLogFile (f, TRUE)) != NULL)
 	     logview_add_log (logview, tl);
    }
@@ -1194,11 +1203,12 @@ static int
 logview_count_logs (void)
 {
 	GSList *list;
+    GList *logs;
 	LogviewWindow *window;
 	int numlogs = 0;
 	for (list = logview_windows; list != NULL; list = g_slist_next (list)) {
 		window = list->data;
-		if (window->curlog != NULL)
+        for (logs = window->logs; logs != NULL; logs = g_list_next (logs))
 			numlogs ++;
 	}
 	return numlogs;
